# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 1}

Name: GeoIP           
Version: 1.6.12
Release: 1
Summary: C library for country/city/organization to IP address or hostname mapping     
Group: Development/Libraries         
License: LGPLv2+
URL: http://www.maxmind.com/app/c            
Source0: http://www.maxmind.com/download/geoip/api/c/%{name}-%{version}.tar.gz 
Source1: %{name}-LICENSE.txt
Source2: fetch-geoipdata-city.pl
Source3: fetch-geoipdata.pl
Source4: %{name}-README
Patch1:  apps.patch
Patch2:  libGeoIP.patch
Patch3:  test.patch
Source5: geoipupdate.cron
# Data sources indexed at http://dev.maxmind.com/geoip/legacy/geolite
Source10:       http://geolite.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz
Source11:       http://geolite.maxmind.com/download/geoip/database/GeoIPv6.dat.gz
Source12:       http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.gz
Source13:       http://geolite.maxmind.com/download/geoip/database/GeoLiteCityv6-beta/GeoLiteCityv6.dat.gz
Source14:       http://download.maxmind.com/download/geoip/database/asnum/GeoIPASNum.dat.gz
Source15:       http://download.maxmind.com/download/geoip/database/asnum/GeoIPASNumv6.dat.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

Obsoletes: geoip < %{version}-%{release}
Provides: geoip = %{version}-%{release}

BuildRequires: automake, autoconf
Requires: libgcc >= 6.3.0-1

%description
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys, and
countries as values. This database should be more complete and accurate than
using reverse DNS lookups.

%package update
Summary:        Crontab entry to facilitate automatic updates of databases
Group:          Applications/Databases
Requires:       %{name} = %{version}-%{release}

%description update
Crontab entry to provide weekly updates of the GeoIP free databases.

%package data
Summary:        Static snapshot of GeoIP databases
Group:          Applications/Databases
Requires:       %{name} = %{version}-%{release}

%description data
Snapshot of IPv4 and IPv6 databases for GeoIP. These databases are not
regularly updated, use a cron job from GeoIP-update package to get fresh ones.

This package includes GeoLite data created by MaxMind, available from
http://www.maxmind.com/


%package devel
Summary: Development headers and libraries for GeoIP     
Group: Development/Libraries         
Requires: %{name} = %{version}-%{release}
Provides: geoip-devel = %{version}-%{release}
Obsoletes: geoip-devel < %{version}-%{release}

%description devel
Development headers and static libraries for building GeoIP-based applications


%prep
%setup -q
%patch1  -R
%patch2  -R
%patch3  -R



install -D -m644 %{SOURCE1} LICENSE.txt
install -D -m644 %{SOURCE2} fetch-geoipdata-city.pl
install -D -m644 %{SOURCE3} fetch-geoipdata.pl
install -D -m644 %{SOURCE5} geoipupdate.cron

# Distribute all databases as *-inital.dat files in GeoIP packages.
# User then can download real .dat files without replacing the ones from
# package.
install -p -m 644 %{SOURCE10} data/GeoIP-initial.dat.gz;        gunzip data/GeoIP-initial.dat
install -p -m 644 %{SOURCE11} data/GeoIPv6-initial.dat.gz;      gunzip data/GeoIPv6-initial.dat
# City and ASN databases will be in GeoIP-data subpackage as -initial files
# and linked to non--initial on installation of the subpackage.
install -p -m 644 %{SOURCE12} data/GeoIPCity-initial.dat.gz;     gunzip data/GeoIPCity-initial.dat
install -p -m 644 %{SOURCE13} data/GeoIPCityv6-initial.dat.gz;  gunzip data/GeoIPCityv6-initial.dat
install -p -m 644 %{SOURCE14} data/GeoIPASNum-initial.dat.gz;   gunzip data/GeoIPASNum-initial.dat
install -p -m 644 %{SOURCE15} data/GeoIPASNumv6-initial.dat.gz; gunzip data/GeoIPASNumv6-initial.dat

cp %{SOURCE1} LICENSE.txt
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} README
# fake a <stdbool.h> as AIX5L V5.1 and XLC/C++ V7 doesn't have one
cat > libGeoIP/stdbool.h << EOF
#ifndef stdbool_h_wrapper
#define stdbool_h_wrapper

typedef enum {false = 0, true = 1} bool;

#endif
EOF
autoreconf -fiv


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X64"
export NM="nm -X64"

export CC="gcc  -maix64 -D_LINUX_SOURCE_COMPAT"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
   --datadir=%{_datadir} \
	--disable-dependency-tracking \
	--enable-shared --disable-static
gmake %{?_smp_mflags}

if [ "%{dotests}" == 1 ]
      then
          (gmake -k check || true)
      fi


cp ./libGeoIP/.libs/libGeoIP.so.1 .



%install
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/GeoIP
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make install DESTDIR=${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/GeoIP

# fetch database updates weekly
install -D -m755 geoipupdate.cron %{buildroot}%{_sysconfdir}/cron.weekly/geoipupdate

# nix the stuff we don't need like .la files.
rm -f %{buildroot}%{_libdir}/*.la
# install downloaded GeoLite databases
for db in \
        GeoIP-initial.dat \
        GeoIPv6-initial.dat \
        GeoIPCity-initial.dat \
        GeoIPCityv6-initial.dat \
        GeoIPASNum-initial.dat \
        GeoIPASNumv6-initial.dat
do
        install -p -m 644 data/$db %{buildroot}%{_datadir}/GeoIP/
done

# create empty files for initial %%ghost databases
touch %{buildroot}%{_datadir}/GeoIP/GeoIP{ASNum,City,Country}{,v6}.dat
chmod 644 %{buildroot}%{_datadir}/GeoIP/GeoIP{ASNum,City,Country}{,v6}.dat

# make the default GeoIP.dat a symlink to our -initial data file.
ln -sf GeoIP-initial.dat %{buildroot}%{_datadir}/GeoIP/GeoIP.dat
ln -sf GeoIPv6-initial.dat %{buildroot}%{_datadir}/GeoIP/GeoIPv6.dat




/usr/bin/strip  -X64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
%post data
# Link *-initial.dat files as official GeoIP database files. Make sure not to
# overwrite any user databases!
for db in GeoIPCity.dat GeoIPCityv6.dat GeoIPASNum.dat GeoIPASNumv6.dat ; do
    db_initial=${db%.dat}-initial.dat
    if [ ! -e "/opt/freeware/share/GeoIP/$db" ]; then
        ln -sf "/opt/freeware/share/GeoIP/$db_initial" "/opt/freeware/share/GeoIP/$db" &>/dev/null || :
    fi
done

%postun data
if [ "$1" == "0" ]; then
    for db in GeoIPCity.dat GeoIPCityv6.dat GeoIPASNum.dat GeoIPASNumv6.dat; do
        db_initial=${db%.dat}-initial.dat
	if [ -h "/opt/freeware/share/GeoIP/$db" ]; then
		file "/opt/freeware/share/GeoIP/$db" | grep "$db_initial"  > /dev/null 
		 if [ $? == 0 ]; then    
			rm "/opt/freeware/share/GeoIP/$db"
		fi        
	fi
    done
fi

%files
%defattr(-,root,system,-)
%doc AUTHORS COPYING ChangeLog README GeoIP*
%{_bindir}/*
%{_libdir}/*.a
%{_mandir}/man1/*.1*
%dir %{_datadir}/GeoIP/
%{_datadir}/GeoIP/GeoIP.dat
%{_datadir}/GeoIP/GeoIPv6.dat
%{_datadir}/GeoIP/GeoIP-initial.dat
%{_datadir}/GeoIP/GeoIPv6-initial.dat
%ghost %{_datadir}/GeoIP/GeoIPASNum.dat
%ghost %{_datadir}/GeoIP/GeoIPCity.dat
%ghost %{_datadir}/GeoIP/GeoIPCountry.dat
%ghost %{_datadir}/GeoIP/GeoIPASNumv6.dat
%ghost %{_datadir}/GeoIP/GeoIPCityv6.dat
%ghost %{_datadir}/GeoIP/GeoIPCountryv6.dat


%files update
%{_sysconfdir}/cron.weekly/geoipupdate

%files data
%{_datadir}/GeoIP/GeoIPCity-initial.dat
%{_datadir}/GeoIP/GeoIPCityv6-initial.dat
%{_datadir}/GeoIP/GeoIPASNum-initial.dat
%{_datadir}/GeoIP/GeoIPASNumv6-initial.dat



%files devel
%defattr(-,system,system,-)
%{_includedir}/*


%changelog
* Tue Mar 12 2019 Harshita Jain <harjain9@in.ibm.com> - 1.6.12-1
- Initial port to AIX TOOLBOX

* Fri Nov 07 2014 Michael Perzl <michael@perzl.org> - 1.5.1-1
- updated to version 1.5.1

* Thu Oct 06 2011 Michael Perzl <michael@perzl.org> - 1.4.8-1
- updated to version 1.4.8

* Thu Oct 06 2011 Michael Perzl <michael@perzl.org> - 1.4.7-1
- updated to version 1.4.7

* Wed May 19 2010 Michael Perzl <michael@perzl.org> - 1.4.7-0.1.20090931cvs
- first version for AIX V5.1 and higher
